OC.L10N.register(
    "core",
    {
    "Please select a file." : "Por favor selecciona un archivo.",
    "File is too big" : "El archivo es demasiado grande.",
    "The selected file is not an image." : "El archivo seleccionado no es una imagen.",
    "The selected file cannot be read." : "El archivo seleccionado no se puede leer.",
    "The file was uploaded" : "El archivo fue cargado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo cargado excede el valor establecido en la directiva upload_max_filesize en el archivo php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo cargado excede el valor especificado de la directiva MAX_FILE_SIZE en la forma de HTML",
    "The file was only partially uploaded" : "El archivo sólo fue cargado parcialmente",
    "No file was uploaded" : "No se cargó el archivo",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No fue posible escribir a disco",
    "A PHP extension stopped the file upload" : "Una extensión de PHP detuvo la carga del archivo",
    "Invalid file provided" : "Archivo proporcionado inválido",
    "No image or file provided" : "No se especificó un archivo o imagen",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "An error occurred. Please contact your admin." : "Se presentó un error. Por favor contacta a tu adminsitrador. ",
    "Invalid image" : "Imagen inválida",
    "No temporary profile picture available, try again" : "No hay una imagen de perfil temporal disponible, por favor inténtalo de nuevo",
    "No crop data provided" : "No se han proporcionado datos del recorte",
    "No valid crop data provided" : "No se han proporcionado datos válidos del recorte",
    "Crop is not square" : "El recorte no es cuadrado",
    "State token does not match" : "La ficha de estado no corresponde",
    "Invalid app password" : "Contraseña de app inválida",
    "Could not complete login" : "No se pudo completar el inicio de sesión",
    "Your login token is invalid or has expired" : "Su token de inicio de sesión no es válido o ha caducado",
    "Login" : "Iniciar sesión",
    "Password reset is disabled" : "Restablecer contraseña se encuentra deshabilitado",
    "Could not reset password because the token is expired" : "No se puede restablecer la contraseña porque el token de autenticación ha caducado.",
    "Could not reset password because the token is invalid" : "No se puede restablecer la contraseña porque el token de autenticación no es válido.",
    "%s password reset" : "%s restablecer la contraseña",
    "Password reset" : "Restablecer contraseña",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Haz click en el siguiente botón para restablecer tu contraseña. Si no has solicitado restablecer su contraseña, por favor ignora este correo. ",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Haz click en la siguiente liga para restablecer su contraseña. Si no has solicitado restablecer la contraseña, por favor ignora este mensaje. ",
    "Reset your password" : "Restablecer tu contraseña",
    "Nextcloud Server" : "Servidor Nextcloud",
    "Some of your link shares have been removed" : "Se han eliminado algunos de sus enlaces compartidos",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Debido a un error de seguridad, tuvimos que eliminar algunos de sus enlaces compartidos. Por favor vea el enlace para más información.",
    "The user limit of this instance is reached." : "Se alcanzó el límite de usuarios de esta instancia.",
    "Preparing update" : "Preparando actualización",
    "[%d / %d]: %s" : "[%d / %d]: %s ",
    "Repair step:" : "Paso de reparación:",
    "Repair info:" : "Información de reparación:",
    "Repair warning:" : "Advertencia de reparación:",
    "Repair error:" : "Error de reparación: ",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Por favor usa el actualizador de línea de comandos ya que el actualizador automático se encuentra deshabilitado en config.php.",
    "Turned on maintenance mode" : "Modo mantenimiento activado",
    "Turned off maintenance mode" : "Modo mantenimiento desactivado",
    "Maintenance mode is kept active" : "El modo mantenimiento sigue activo",
    "Updating database schema" : "Actualizando esquema de base de datos",
    "Updated database" : "Base de datos actualizada",
    "Update app \"%s\" from App Store" : "Actualizar la aplicación \"%s\" desde la App Store",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Verificando si el esquema de la base de datos para %s puede ser actualizado (esto puede tomar mucho tiempo dependiendo del tamaño de la base de datos)",
    "Updated \"%1$s\" to %2$s" : "\"%1$s\" actualizado a %2$s",
    "Set log level to debug" : "Establecer nivel de bitacora a depurar",
    "Reset log level" : "Restablecer nivel de bitácora",
    "Starting code integrity check" : "Comenzando verificación de integridad del código",
    "Finished code integrity check" : "Terminó la verificación de integridad del código ",
    "%s (incompatible)" : "%s (incompatible)",
    "The following apps have been disabled: %s" : "Las siguientes aplicaciones han sido deshabilitadas: %s",
    "Already up to date" : "Ya está actualizado",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Tu servidor web aún no esta correctamente configurado para permitir la sincronización de archivos porque la interfaz WebDAV parece estar rota. ",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Su servidor no está configurado correctamente para resolver \"{url}\". Se puede encontrar más información en la {linkstart}documentación ↗{linkend}.",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Tu servidor no está bien configurado para resolver \"{url}\". Esto podría estar relacionado con que la configuración del servidor web que no se ha actualizado para entregar esta carpeta directamente. Por favor, compara tu configuración con las reglas de reescritura del \".htaccess\" para Apache o la provista para Nginx en la {linkstart}página de documentación ↗{linkend}. En Nginx, suelen ser las líneas que empiezan con \"location ~\" las que hay que actualizar.",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Tu servidor web no está bien configurado para suministrar archivos .woff2 . Esto suele ser un problema de la configuración de Nginx. Para Nextcloud 15, necesita un ajuste para suministrar archivos .woff2. Compare su configuración de Nginx con la configuración recomendada en nuestra {linkstart}documentación ↗{linkend}.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP no parece estar configurado correctamente para consultar las variables de ambiente. La prueba con getenv(\"PATH\") sólo regresa una respuesta vacía.",
    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Por favor, compruebe las notas de configuración de PHP en la {linkstart}documentación de instalación ↗{linkend} y la configuración de PHP de su servidor, especialmente cuando se utiliza php-fpm.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Se ha activado la configuración de solo lectura. Esto evita cambiar ciertas configuraciones vía la interfaz web. Además, el archivo debe hacerse escribible de manera manual para cada actualización.",
    "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "No has configurado o verificado todavía los datos de servidor de correo. Por favor, dirígete a la {mailSettingsStart}Configuración básica{mailSettingsEnd} para hacerlo. A continuación, usa el botón de \"Enviar correo\" bajo el formulario para verificar tu configuración.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Tu base de datos no puede correr con el nivel de aislamiento de transacción de \"READ COMMITTED\".  Puede causar problemas cuando mútiples acciones sean ejecutadas en paralelo.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "El modulo PHP 'fileinfo' no ha sido encontrado. Te recomendamos ámpliamente que habilites este módulo para obtener los mejores resultados en la detección de tipos MIME. ",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "No fue posible ejecutar el trabajo de cron via CLI. Se presentaron los siguientes errores técnicos:",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "La función de PHP \"set_time_limit\" no está disponible. Esto podría generar que la ejecución de scripts se detenga, rompiendo su instalación. Se recomienda ámpliamente habilitar esta función. ",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Tu PHP no cuenta con soporte FreeType, lo que resulta en fallas en la imagen de perfil y la interface de configuraciones. ",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Actualmente estás usando SQLite como el backend de base de datos. Para instalaciones más grandes te recomendamos cambiar a un backend de base de datos diferente.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Esto es particularmente recomendado cuando se usa el cliente de escritorio para sincronización de archivos. ",
    "Error occurred while checking server setup" : "Se presentó un error al verificar la configuración del servidor",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "El encabezado HTTP \"{header}\" está establecido a \"{expected}\". Esto representa un riesgo potencial de seguridad o privacidad, y que se recomienda ajustar esta configuración. ",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "El encabezado HTTP \"{header}\" no está establecido a \"{expected}\". Puede que lgunas características no funcionen correctamente, y se recomienda ajustar esta confirguración. ",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "Se está accediendo al sitio de manera insegura mediante HTTP. Se recomienda ampliamente que configure su servidor para que requiera HTTPS, como se describe en los {linkstart}consejos de seguridad ↗{linkend}.",
    "unknown text" : "texto desconocido",
    "Hello world!" : "¡Hola mundo!",
    "sunny" : "soleado",
    "Hello {name}, the weather is {weather}" : "Hola {name}, el clima es {weather}",
    "Hello {name}" : "Hola {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Estos son los resultados de tu búsqueda <script>alert(1)</script></strong>",
    "new" : "nuevo",
    "_download %n file_::_download %n files_" : ["Descargar %n archivos","Descargar %n archivos","Descargar %n archivos"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "La actualización está en curso, abandonar esta página puede interrumpir el proceso en algunos ambientes. ",
    "Update to {version}" : "Actualizar a {version}",
    "An error occurred." : "Se presentó un error.",
    "Please reload the page." : "Por favor vuelve a cargar la página.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La actualización no fue exitosa. Para más información <a href=\"{url}\">consulta nuestro comentario  en el foro </a> que cubre este tema. ",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "La actualización no fue exitosa. Por favor reporta este tema a la <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Comunidad Nextcloud</a>.",
    "Continue to {productName}" : "Continuar a {productName}",
    "More apps" : "Más aplicaciones",
    "Log in" : "Ingresar",
    "Logging in …" : "Iniciando sesión ...",
    "Server side authentication failed!" : "¡Falló la autenticación del lado del servidor!",
    "Please contact your administrator." : "Por favor contacta al administrador.",
    "An internal error occurred." : "Se presentó un error interno.",
    "Please try again or contact your administrator." : "Por favor vuelve a intentarlo o contacta a tu adminsitrador. ",
    "Password" : "Contraseña",
    "Wrong username or password." : "Usuario o contraseña equivocado. ",
    "User disabled" : "Usuario deshabilitado",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Hemos detectado múltiples intentos de inicio de sesión desde tu IP. Por lo tanto tu siguiente incio de sesión se retrasará hasta 30 segundos. ",
    "Username or email" : "Usuario o correo electrónico",
    "Your account is not setup for passwordless login." : "Tu cuenta no está configurada para iniciar de sesión sin contraseña",
    "Browser not supported" : "Navegador no compatible",
    "Passwordless authentication is not supported in your browser." : "La autenticación sin contraseña no está soportada en tu navegador.",
    "Your connection is not secure" : "Tu conexión no es segura",
    "Passwordless authentication is only available over a secure connection." : "La autenticación sin contraseña solo está disponible bajo una conexión segura.",
    "Reset password" : "Restablecer contraseña",
    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Se envió un mensaje para reestablecer la contraseña a la dirección de correo electrónico de esta cuenta. Si no lo recibes, comprueba si está en el buzón de Correo No Deseado/Spam o pide ayuda a tu administrador local.",
    "If it is not there ask your local administrator." : "Si no está ahí ponte en contacto con el administrador local",
    "Couldn't send reset email. Please contact your administrator." : "No fue posible enviar el correo de restauración. Por favor contacta a tu adminsitrador. ",
    "Password cannot be changed. Please contact your administrator." : "La contraseña no puede ser cambiada. Por favor, contacte con su administrador.",
    "Back to login" : "Regresar al inicio de sesión",
    "New password" : "Nueva contraseña",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Sus archivos están encriptados. No habrá forma de recuperar sus datos después de restablecer su contraseña. Si no está seguro de qué hacer, contacte a su administrador antes de continuar. ¿Realmente desea continuar?",
    "I know what I'm doing" : "Sé lo que estoy haciendo",
    "Resetting password" : "Reestableciendo contraseña",
    "Recommended apps" : "Aplicaciones recomendadas",
    "Loading apps …" : "Cargando aplicaciones ...",
    "Could not fetch list of apps from the App Store." : "No es posible obtener la lista de aplicaciones de la App Store.",
    "Installing apps …" : "Instalando aplicaciones ...",
    "Skip" : "Saltar",
    "Install recommended apps" : "Instalar las aplicaciones recomendadas",
    "Forgot password?" : "¿Olvidaste tu contraseña?",
    "Back" : "Atrás",
    "Reset search" : "Reestablecer búsqueda",
    "Search" : "Buscar",
    "Settings" : "Configuraciones ",
    "Could not load your contacts" : "No fue posible cargar tus contactos",
    "Search contacts …" : "Buscar contactos ...",
    "No contacts found" : "No se encontraron contactos",
    "Show all contacts …" : "Mostrar todos los contactos ...",
    "Loading your contacts …" : "Cargando sus contactos ... ",
    "Looking for {term} …" : "Buscando {term} ...",
    "No" : "No",
    "Yes" : "Sí",
    "No files in here" : "No hay archivos aquí",
    "New folder" : "Carpeta nueva ",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "\"{name}\" is an invalid file name." : "\"{name}\" es un nombre de archivo inválido. ",
    "File name cannot be empty." : "El nombre de archivo no puede estar vacío.",
    "\"/\" is not allowed inside a file name." : "No se permite el uso del caracter \"/\" en el nombre del archivo.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" no es in tipo de archivo permitido",
    "{newName} already exists" : "{newName} ya existe",
    "Choose" : "Seleccionar",
    "Copy" : "Copiar",
    "Move" : "Mover",
    "Error loading file picker template: {error}" : "Se presentó un error al cargar la plantilla del seleccionador de archivos: {error}",
    "OK" : "OK",
    "Error loading message template: {error}" : "Se presentó un error al cargar la plantilla del mensaje: {error}",
    "read-only" : "sólo-lectura",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflicto de archivo","{count} conflictos en el archivo","{count} conflictos en el archivo"],
    "One file conflict" : "Un conflicto en el archivo",
    "New Files" : "Archivos Nuevos",
    "Already existing files" : "Archivos ya existentes",
    "Which files do you want to keep?" : "¿Cuáles archivos deseas mantener?",
    "If you select both versions, the copied file will have a number added to its name." : "Si seleccionas ambas versiones, se le agregará un número al nombre del archivo copiado.",
    "Cancel" : "Cancelar",
    "Continue" : "Continuar",
    "(all selected)" : "(todos seleccionados)",
    "({count} selected)" : "({count} seleccionados)",
    "Error loading file exists template" : "Se presentó un error al cargar la plantilla de existe archivo ",
    "Pending" : "Pendiente",
    "Copy to {folder}" : "Copiar a {folder}",
    "Move to {folder}" : "Mover a {folder}",
    "Authentication required" : "Se requiere autenticación",
    "This action requires you to confirm your password" : "Esta acción requiere que confirmes tu contraseña",
    "Confirm" : "Confirmar",
    "Failed to authenticate, try again" : "Falla en la autenticación, por favor reintentalo",
    "seconds ago" : "hace segundos",
    "Connection to server lost" : "Se ha perdido la conexión con el servidor",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Se presentó un error al cargar la página, recargando en %n segundo","Se presentó un error al cargar la página, recargando en %n segundos","Se presentó un error al cargar la página, recargando en %n segundos"],
    "Hide details" : "Ocultar detalles",
    "Very weak password" : "Contraseña muy débil",
    "Weak password" : "Contraseña débil",
    "So-so password" : "Contraseña aceptable",
    "Good password" : "Buena contraseña",
    "Strong password" : "Contraseña fuerte",
    "No action available" : "No hay acciones disponibles",
    "Error fetching contact actions" : "Se presentó un error al traer las acciónes de contatos",
    "Non-existing tag #{tag}" : "Etiqueta #{tag} no-existente",
    "Restricted" : "Restringido",
    "Invisible" : "Invisible",
    "Delete" : "Borrar",
    "Rename" : "Renombrar",
    "Collaborative tags" : "Etiquetas colaborativas",
    "No tags found" : "No se encontraron etiquetas",
    "Personal" : "Personal",
    "Users" : "Usuarios",
    "Apps" : "Aplicaciones",
    "Admin" : "Administración",
    "Help" : "Ayuda",
    "Access forbidden" : "Acceso prohibido",
    "Page not found" : "Página no encontrada",
    "Error" : "Error",
    "Previous" : "Previo",
    "Internal Server Error" : "Error interno del servidor",
    "The server was unable to complete your request." : "El servidor no pudo completar tu solicitud.",
    "If this happens again, please send the technical details below to the server administrator." : "Si esto vuelve a suceder, por favor envia los detalles tecnicos siguientes al adminsitrador del sistema.",
    "More details can be found in the server log." : "Puedes consultar más detalles en la bitácora del servidor. ",
    "Technical details" : "Detalles técnicos",
    "Remote Address: %s" : "Dirección Remota: %s",
    "Request ID: %s" : "ID de solicitud: %s",
    "Type: %s" : "Tipo: %s",
    "Code: %s" : "Código: %s",
    "Message: %s" : "Mensaje: %s",
    "File: %s" : "Archivo: %s",
    "Line: %s" : "Línea: %s",
    "Trace" : "Rastrear",
    "Security warning" : "Advertencia de seguridad",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Tu directorio de datos y sus archivos probablemente sean accesibles desde Internet ya que el archivo .htaccess no funciona.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para más información de como configurar correctaemente tu servidor, por favor consulta la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentación</a>.",
    "Create an <strong>admin account</strong>" : "Crear una <strong>cuenta de administrador</strong>",
    "Username" : "Usuario",
    "Show password" : "Mostrar contraseña",
    "Storage & database" : "Almacenamiento & base de datos",
    "Data folder" : "Carpeta de datos",
    "Configure the database" : "Configurar la base de datos",
    "Only %s is available." : "Sólo %s está disponible.",
    "Install and activate additional PHP modules to choose other database types." : "Instala y activa módulos adicionales de PHP para seleccionar otros tipos de bases de datos. ",
    "For more details check out the documentation." : "Por favor consulta la documentación para más detalles. ",
    "Database user" : "Usuario de la base de datos",
    "Database password" : "Contraseña de la base de datos",
    "Database name" : "Nombre de la base de datos",
    "Database tablespace" : "Espacio de tablas en la base de datos",
    "Database host" : "Servidor de base de datos",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Por favor especifica el número de puerto así como el nombre del servidor (ejem., localhost:5432).",
    "Performance warning" : "Advertencia de desempeño",
    "Need help?" : "¿Necesitas ayuda?",
    "See the documentation" : "Ver la documentación",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicación requiere de JavaScript para su correcta operación. Por favor {linkstart}habilita JavaScript{linkend} y vuelve a cargar la página. ",
    "Contacts" : "Contactos",
    "Contacts menu" : "Menú de Contactos",
    "Confirm your password" : "Confirma tu contraseña",
    "Connect to your account" : "Conectate a tu cuenta",
    "App token" : "Ficha de la aplicación",
    "Grant access" : "Conceder acceso",
    "Alternative log in using app token" : "Inicio de sesión alternativo usando una ficha de aplicación",
    "Account access" : "Acceo de cuenta",
    "This share is password-protected" : "Este elemento compartido está protegido con contraseña",
    "Go to %s" : "Ir a %s",
    "Two-factor authentication" : "Autenticación de dos-factores",
    "Use backup code" : "Usar código de respaldo",
    "Error while validating your second factor" : "Se presentó un error al validar tu segundo factor",
    "Access through untrusted domain" : "Accesa a través de un dominio no de confianza",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Por favor contacta a tu adminsitrador. Si tu eres un administrador, edita la propiedad \"trusted_domains\" en el archivo config/config.php como en el ejemplo config.sample.php.",
    "App update required" : "Se requiere una actualización de la aplicación",
    "These incompatible apps will be disabled:" : "Las siguientes aplicaciones incompatibles serán deshabilitadas:",
    "The theme %s has been disabled." : "El tema %s ha sido deshabilitado. ",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Por favor asegurarte de que la base de datos, la carpeta de configuración y las carpetas de datos hayan sido respaldadas antes de continuar. ",
    "Start update" : "Iniciar actualización",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar la expiración de tiempo en instalaciones grandes, puedes ejecutar el siguiente comando desde tu directorio de instalación:",
    "Detailed logs" : "Bitácoras detalladas",
    "Update needed" : "Se requiere de una actualización",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Favor de usar el actualizador desde la línea de comandos ya que tu instancia cuenta con más de 50 usuarios.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Para más ayuda, por favor consulta la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentación</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Estoy conciente de que si continúo haciendo la actualización vía web, la interfaz de usuario corre el riesgo de que el tiempo de la solicitud expire y cause pérdida de datos, pero cuento con un respaldo y sé como restaurar mi instancia en caso de una falla. ",
    "Upgrade via web on my own risk" : "Actualizar vía Web bajo mi propio riesgo",
    "This %s instance is currently in maintenance mode, which may take a while." : "Esta instancia %s se encuentra actualmente en modo mantenimiento, que podría tomar algo de tiempo. ",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacta a tu administrador del sistema si este mensaje persiste o se presentó de manera inesperada.",
    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Introduzca su clave de suscripción para aumentar el límite de usuarios. Para obtener más información sobre Nextcloud Enterprise, visite nuestro sitio web.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Verificando tabla %s",
    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "El servidor no cuenta con una conexión a Internet: No se pudieron alcanzar múltiples endpoints. Esto significa que algunas características como montar almacenamiento externo, notificaciones de actualizaciones o instalación de aplicaciones de 3ros no funcionarán correctamente. Acceder archivos de forma remota y el envío de de notificaciones por correo electrónico puede que no funcionen tampoco. Establece una conexión desde este servidor a Internet para aprovechar todas las funcionalidades.",
    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Probablemente tu directorio de datos y archivos sean accesibles desde Internet. El archivo .htaccess no está funcionando. Se recomienda ampliamente que configures tu servidor web para que el directorio de datos no sea accesible, o bien, que muevas el directorio de datos fuera del directorio raíz del servidor web.",
    "restricted" : "restringido",
    "invisible" : "invisible",
    "File not found" : "Archivo no encontrado",
    "More" : "Más",
    "More apps menu" : "Menú de más aplicaciones",
    "Settings menu" : "Menú de Configuraciones",
    "The password is wrong. Try again." : "La contraseña está equivoada. Por favor vuelve a intentarlo. ",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "El lanzamiento de esta versión para la comunidad de Nextcloud no cuenta con soporte y las notificaciones instantáneas no están disponibles."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
